@@ -1,13 +1,13 @@
 use std::path::PathBuf;
 
-use image_hasher::{FilterType, HashAlg};
-
+use czkawka_core::CZKAWKA_VERSION;
 use czkawka_core::common_dir_traversal::CheckingMethod;
 use czkawka_core::common_tool::DeleteMethod;
-use czkawka_core::duplicate::HashType;
-use czkawka_core::same_music::MusicSimilarity;
-use czkawka_core::similar_images::SimilarityPreset;
-use czkawka_core::CZKAWKA_VERSION;
+use czkawka_core::tools::broken_files::CheckedTypes;
+use czkawka_core::tools::duplicate::HashType;
+use czkawka_core::tools::same_music::MusicSimilarity;
+use czkawka_core::tools::similar_images::SimilarityPreset;
+use image_hasher::{FilterType, HashAlg};
 
 #[derive(clap::Parser)]
 #[clap(
@@ -25,7 +25,7 @@ pub enum Commands {
     #[clap(
         name = "dup",
         about = "Finds duplicate files",
-        after_help = "EXAMPLE:\n    czkawka dup -d /home/rafal -e /home/rafal/Obrazy  -m 25 -x 7z rar IMAGE -s hash -f results.txt -D aeo"
+        after_help = "EXAMPLE:\n    czkawka dup -d /home/rafal - -e /home/rafal/Obrazy  -m 25 -x 7z rar IMAGE -s hash -f results.txt -D aeo"
     )]
     Duplicates(DuplicatesArgs),
     #[clap(
@@ -77,23 +77,33 @@ pub enum Commands {
     #[clap(
         name = "ext",
         about = "Finds files with invalid extensions",
-        after_help = "EXAMPLE:\n    czkawka broken -d /home/czokolada/ -f results.txt"
+        after_help = "EXAMPLE:\n    czkawka ext -d /home/czokolada/ -f results.txt"
     )]
     BadExtensions(BadExtensionsArgs),
-    #[clap(name = "tester", about = "Small utility to test supported speed of ", after_help = "EXAMPLE:\n    czkawka tester")]
-    Tester,
 }
 
 #[derive(Debug, clap::Args)]
 pub struct DuplicatesArgs {
     #[clap(flatten)]
-    pub thread_number: ThreadNumber,
+    pub common_cli_items: CommonCliItems,
     #[clap(flatten)]
-    pub directories: Directories,
-    #[clap(flatten)]
-    pub excluded_directories: ExcludedDirectories,
-    #[clap(flatten)]
-    pub excluded_items: ExcludedItems,
+    pub reference_directories: ReferenceDirectories,
+    #[clap(
+        short = 'Z',
+        long,
+        value_parser = parse_minimal_file_size,
+        default_value = "257144",
+        help = "Minimum prehash cache file size in bytes",
+        long_help = "Minimum size of prehash cached files in bytes"
+    )]
+    pub minimal_prehash_cache_file_size: u64,
+    #[clap(
+        short = 'u',
+        long,
+        help = "Use prehash cache",
+        long_help = "Use prehash cache to speed up the scanning process by avoiding rehashing files that have already been hashed"
+    )]
+    pub use_prehash_cache: bool,
     #[clap(
         short,
         long,
@@ -121,8 +131,6 @@ pub struct DuplicatesArgs {
         long_help = "Minimum size of cached files in bytes, assigning bigger value may speed up the scan but loading the cache will be slower, assigning smaller value may slow down the scan and some files may need to be hashed again but loading the cache will be faster"
     )]
     pub minimal_cached_file_size: u64,
-    #[clap(flatten)]
-    pub allowed_extensions: AllowedExtensions,
     #[clap(
         short,
         long,
@@ -143,18 +151,7 @@ pub struct DuplicatesArgs {
     )]
     pub hash_type: HashType,
     #[clap(flatten)]
-    pub file_to_save: FileToSave,
-    #[clap(flatten)]
-    pub json_compact_file_to_save: JsonCompactFileToSave,
-    #[clap(flatten)]
-    pub json_pretty_file_to_save: JsonPrettyFileToSave,
-    #[clap(flatten)]
-    pub not_recursive: NotRecursive,
-    #[clap(flatten)]
     pub case_sensitive_name_comparison: CaseSensitiveNameComparison,
-    #[cfg(target_family = "unix")]
-    #[clap(flatten)]
-    pub exclude_other_filesystems: ExcludeOtherFilesystems,
     #[clap(flatten)]
     pub allow_hard_links: AllowHardLinks,
     #[clap(flatten)]
@@ -164,117 +161,45 @@ pub struct DuplicatesArgs {
 #[derive(Debug, clap::Args)]
 pub struct EmptyFoldersArgs {
     #[clap(flatten)]
-    pub thread_number: ThreadNumber,
-    #[clap(flatten)]
-    pub directories: Directories,
-    #[clap(flatten)]
-    pub excluded_directories: ExcludedDirectories,
-    #[clap(flatten)]
-    pub excluded_items: ExcludedItems,
+    pub common_cli_items: CommonCliItems,
     #[clap(short = 'D', long, help = "Delete found folders")]
     pub delete_folders: bool,
-    #[clap(flatten)]
-    pub file_to_save: FileToSave,
-    #[clap(flatten)]
-    pub json_compact_file_to_save: JsonCompactFileToSave,
-    #[clap(flatten)]
-    pub json_pretty_file_to_save: JsonPrettyFileToSave,
-    #[cfg(target_family = "unix")]
-    #[clap(flatten)]
-    pub exclude_other_filesystems: ExcludeOtherFilesystems,
 }
 
 #[derive(Debug, clap::Args)]
 pub struct BiggestFilesArgs {
     #[clap(flatten)]
-    pub thread_number: ThreadNumber,
-    #[clap(flatten)]
-    pub directories: Directories,
-    #[clap(flatten)]
-    pub excluded_directories: ExcludedDirectories,
-    #[clap(flatten)]
-    pub excluded_items: ExcludedItems,
-    #[clap(flatten)]
-    pub allowed_extensions: AllowedExtensions,
+    pub common_cli_items: CommonCliItems,
     #[clap(short, long, default_value = "50", help = "Number of files to be shown")]
     pub number_of_files: usize,
     #[clap(short = 'D', long, help = "Delete found files")]
     pub delete_files: bool,
-    #[clap(flatten)]
-    pub file_to_save: FileToSave,
-    #[clap(flatten)]
-    pub json_compact_file_to_save: JsonCompactFileToSave,
-    #[clap(flatten)]
-    pub json_pretty_file_to_save: JsonPrettyFileToSave,
-    #[clap(flatten)]
-    pub not_recursive: NotRecursive,
     #[clap(short = 'J', long, help = "Finds the smallest files instead the biggest")]
     pub smallest_mode: bool,
-    #[cfg(target_family = "unix")]
-    #[clap(flatten)]
-    pub exclude_other_filesystems: ExcludeOtherFilesystems,
 }
 
 #[derive(Debug, clap::Args)]
 pub struct EmptyFilesArgs {
     #[clap(flatten)]
-    pub thread_number: ThreadNumber,
-    #[clap(flatten)]
-    pub directories: Directories,
-    #[clap(flatten)]
-    pub excluded_directories: ExcludedDirectories,
-    #[clap(flatten)]
-    pub excluded_items: ExcludedItems,
-    #[clap(flatten)]
-    pub allowed_extensions: AllowedExtensions,
+    pub common_cli_items: CommonCliItems,
     #[clap(short = 'D', long, help = "Delete found files")]
     pub delete_files: bool,
-    #[clap(flatten)]
-    pub file_to_save: FileToSave,
-    #[clap(flatten)]
-    pub json_compact_file_to_save: JsonCompactFileToSave,
-    #[clap(flatten)]
-    pub json_pretty_file_to_save: JsonPrettyFileToSave,
-    #[clap(flatten)]
-    pub not_recursive: NotRecursive,
-    #[cfg(target_family = "unix")]
-    #[clap(flatten)]
-    pub exclude_other_filesystems: ExcludeOtherFilesystems,
 }
 
 #[derive(Debug, clap::Args)]
 pub struct TemporaryArgs {
     #[clap(flatten)]
-    pub thread_number: ThreadNumber,
-    #[clap(flatten)]
-    pub directories: Directories,
-    #[clap(flatten)]
-    pub excluded_directories: ExcludedDirectories,
-    #[clap(flatten)]
-    pub excluded_items: ExcludedItems,
+    pub common_cli_items: CommonCliItems,
     #[clap(short = 'D', long, help = "Delete found files")]
     pub delete_files: bool,
-    #[clap(flatten)]
-    pub file_to_save: FileToSave,
-    #[clap(flatten)]
-    pub json_compact_file_to_save: JsonCompactFileToSave,
-    #[clap(flatten)]
-    pub json_pretty_file_to_save: JsonPrettyFileToSave,
-    #[clap(flatten)]
-    pub not_recursive: NotRecursive,
-    #[cfg(target_family = "unix")]
-    #[clap(flatten)]
-    pub exclude_other_filesystems: ExcludeOtherFilesystems,
 }
 
 #[derive(Debug, clap::Args)]
 pub struct SimilarImagesArgs {
     #[clap(flatten)]
-    pub thread_number: ThreadNumber,
+    pub common_cli_items: CommonCliItems,
     #[clap(flatten)]
-    pub directories: Directories,
-    #[clap(flatten)]
-    pub excluded_directories: ExcludedDirectories,
+    pub reference_directories: ReferenceDirectories,
     #[clap(
         short,
         long,
@@ -303,28 +228,19 @@ pub struct SimilarImagesArgs {
     )]
     pub similarity_preset: SimilarityPreset,
     #[clap(flatten)]
-    pub excluded_items: ExcludedItems,
-    #[clap(flatten)]
-    pub file_to_save: FileToSave,
-    #[clap(flatten)]
     pub delete_method: DMethod,
     #[clap(flatten)]
+    pub allow_hard_links: AllowHardLinks,
+    #[clap(flatten)]
     pub dry_run: DryRun,
     #[clap(flatten)]
-    pub json_compact_file_to_save: JsonCompactFileToSave,
-    #[clap(flatten)]
-    pub json_pretty_file_to_save: JsonPrettyFileToSave,
-    #[clap(flatten)]
-    pub not_recursive: NotRecursive,
-    #[cfg(target_family = "unix")]
-    #[clap(flatten)]
-    pub exclude_other_filesystems: ExcludeOtherFilesystems,
+    pub ignore_same_size: IgnoreSameSize,
     #[clap(
         short = 'g',
         long,
         default_value = "Gradient",
         value_parser = parse_similar_hash_algorithm,
-        help = "Hash algorithm (allowed: Mean, Gradient, Blockhash, VertGradient, DoubleGradient)"
+        help = "Hash algorithm (allowed: Mean, Gradient, Blockhash, VertGradient, DoubleGradient, Median)"
     )]
     pub hash_alg: HashAlg,
     #[clap(
@@ -348,17 +264,17 @@ pub struct SimilarImagesArgs {
 #[derive(Debug, clap::Args)]
 pub struct SameMusicArgs {
     #[clap(flatten)]
-    pub thread_number: ThreadNumber,
+    pub common_cli_items: CommonCliItems,
     #[clap(flatten)]
-    pub directories: Directories,
-    #[clap(flatten)]
-    pub excluded_directories: ExcludedDirectories,
-    #[clap(flatten)]
-    pub excluded_items: ExcludedItems,
+    pub reference_directories: ReferenceDirectories,
     #[clap(flatten)]
     pub delete_method: DMethod,
     #[clap(flatten)]
     pub dry_run: DryRun,
+    #[clap(short, long, help = "Approximate comparison of music tags.")]
+    pub approximate_comparison: bool,
+    #[clap(short, long, help = "Compare fingerprints only with similar titles.")]
+    pub compare_fingerprints_only_with_similar_titles: bool,
     #[clap(
         short = 'z',
         long,
@@ -377,17 +293,6 @@ pub struct SameMusicArgs {
         long_help = "Methods to search files.\nCONTENT - finds similar audio files by content, TAGS - finds similar images by tags, needs to set"
     )]
     pub search_method: CheckingMethod,
-    #[clap(flatten)]
-    pub file_to_save: FileToSave,
-    #[clap(flatten)]
-    pub json_compact_file_to_save: JsonCompactFileToSave,
-    #[clap(flatten)]
-    pub json_pretty_file_to_save: JsonPrettyFileToSave,
-    #[clap(flatten)]
-    pub not_recursive: NotRecursive,
-    #[cfg(target_family = "unix")]
-    #[clap(flatten)]
-    pub exclude_other_filesystems: ExcludeOtherFilesystems,
     #[clap(
         short,
         long,
@@ -416,7 +321,7 @@ pub struct SameMusicArgs {
     )]
     pub minimum_segment_duration: f32,
     #[clap(
-        short = 'd',
+        short = 'Y',
         long,
         value_parser = parse_maximum_difference,
         default_value = "2.0",
@@ -458,84 +363,42 @@ fn parse_minimum_segment_duration(src: &str) -> Result<f32, String> {
 #[derive(Debug, clap::Args)]
 pub struct InvalidSymlinksArgs {
     #[clap(flatten)]
-    pub thread_number: ThreadNumber,
-    #[clap(flatten)]
-    pub directories: Directories,
-    #[clap(flatten)]
-    pub excluded_directories: ExcludedDirectories,
-    #[clap(flatten)]
-    pub excluded_items: ExcludedItems,
-    #[clap(flatten)]
-    pub allowed_extensions: AllowedExtensions,
+    pub common_cli_items: CommonCliItems,
     #[clap(short = 'D', long, help = "Delete found files")]
     pub delete_files: bool,
-    #[clap(flatten)]
-    pub file_to_save: FileToSave,
-    #[clap(flatten)]
-    pub json_compact_file_to_save: JsonCompactFileToSave,
-    #[clap(flatten)]
-    pub json_pretty_file_to_save: JsonPrettyFileToSave,
-    #[clap(flatten)]
-    pub not_recursive: NotRecursive,
-    #[cfg(target_family = "unix")]
-    #[clap(flatten)]
-    pub exclude_other_filesystems: ExcludeOtherFilesystems,
 }
 
 #[derive(Debug, clap::Args)]
 pub struct BrokenFilesArgs {
     #[clap(flatten)]
-    pub thread_number: ThreadNumber,
-    #[clap(flatten)]
-    pub directories: Directories,
-    #[clap(flatten)]
-    pub excluded_directories: ExcludedDirectories,
-    #[clap(flatten)]
-    pub excluded_items: ExcludedItems,
-    #[clap(flatten)]
-    pub allowed_extensions: AllowedExtensions,
+    pub common_cli_items: CommonCliItems,
     #[clap(short = 'D', long, help = "Delete found files")]
     pub delete_files: bool,
-    #[clap(flatten)]
-    pub file_to_save: FileToSave,
-    #[clap(flatten)]
-    pub json_compact_file_to_save: JsonCompactFileToSave,
-    #[clap(flatten)]
-    pub json_pretty_file_to_save: JsonPrettyFileToSave,
-    #[clap(flatten)]
-    pub not_recursive: NotRecursive,
-    #[cfg(target_family = "unix")]
-    #[clap(flatten)]
-    pub exclude_other_filesystems: ExcludeOtherFilesystems,
+    #[clap(
+        short,
+        long,
+        default_value = "PDF",
+        value_parser = parse_broken_files,
+        help = "Checking file types (PDF, AUDIO, IMAGE, ARCHIVE)",
+        long_help = "Methods to search files - default PDF.\nPDF - finds broken PDF files,\nAUDIO - finds broken audio files,\nIMAGE - finds broken image files,\nARCHIVE - finds broken archive files"
+    )]
+    pub checked_types: Vec<CheckedTypes>,
 }
 
 #[derive(Debug, clap::Args)]
 pub struct SimilarVideosArgs {
     #[clap(flatten)]
-    pub thread_number: ThreadNumber,
+    pub common_cli_items: CommonCliItems,
     #[clap(flatten)]
-    pub directories: Directories,
-    #[clap(flatten)]
-    pub excluded_directories: ExcludedDirectories,
-    #[clap(flatten)]
-    pub excluded_items: ExcludedItems,
+    pub reference_directories: ReferenceDirectories,
     #[clap(flatten)]
     pub delete_method: DMethod,
     #[clap(flatten)]
+    pub allow_hard_links: AllowHardLinks,
+    #[clap(flatten)]
     pub dry_run: DryRun,
     #[clap(flatten)]
-    pub file_to_save: FileToSave,
-    #[clap(flatten)]
-    pub json_compact_file_to_save: JsonCompactFileToSave,
-    #[clap(flatten)]
-    pub json_pretty_file_to_save: JsonPrettyFileToSave,
-    #[clap(flatten)]
-    pub allowed_extensions: AllowedExtensions,
-    #[clap(flatten)]
-    pub not_recursive: NotRecursive,
-    #[cfg(target_family = "unix")]
-    #[clap(flatten)]
-    pub exclude_other_filesystems: ExcludeOtherFilesystems,
+    pub ignore_same_size: IgnoreSameSize,
     #[clap(
         short,
         long,
@@ -568,26 +431,69 @@ pub struct SimilarVideosArgs {
 #[derive(Debug, clap::Args)]
 pub struct BadExtensionsArgs {
     #[clap(flatten)]
-    pub thread_number: ThreadNumber,
-    #[clap(flatten)]
-    pub directories: Directories,
-    #[clap(flatten)]
-    pub excluded_directories: ExcludedDirectories,
-    #[clap(flatten)]
-    pub excluded_items: ExcludedItems,
-    #[clap(flatten)]
-    pub allowed_extensions: AllowedExtensions,
+    pub common_cli_items: CommonCliItems,
+}
+
+#[derive(Debug, clap::Args)]
+pub struct CommonCliItems {
+    #[clap(short = 'T', long, default_value = "0", help = "Limits thread number, 0(default) will use all available threads")]
+    pub thread_number: usize,
+    #[clap(
+        short,
+        long,
+        required = true,
+        help = "Directorie(s) to search",
+        long_help = "List of directorie(s) which will be searched(absolute path) - this directories are not set as reference folders"
+    )]
+    pub directories: Vec<PathBuf>,
+    #[clap(
+        short,
+        long,
+        help = "Excluded directorie(s)",
+        long_help = "List of directorie(s) which will be excluded from search(absolute path)"
+    )]
+    pub excluded_directories: Vec<PathBuf>,
+    #[clap(
+        short = 'E',
+        long,
+        help = "Excluded item(s)",
+        long_help = "List of excluded item(s) which contains * wildcard(may be slow, so use -e where possible)"
+    )]
+    pub excluded_items: Vec<String>,
+    #[clap(
+        short = 'x',
+        long,
+        help = "Allowed file extension(s)",
+        long_help = "List of checked files with provided extension(s). There are also helpful macros which allow to easy use a typical extensions like:\nIMAGE(\"jpg,kra,gif,png,bmp,tiff,hdr,svg\"),\nTEXT(\"txt,doc,docx,odt,rtf\"),\nVIDEO(\"mp4,flv,mkv,webm,vob,ogv,gifv,avi,mov,wmv,mpg,m4v,m4p,mpeg,3gp\") or\nMUSIC(\"mp3,flac,ogg,tta,wma,webm\")\n "
+    )]
+    pub allowed_extensions: Vec<String>,
+    #[clap(short = 'P', long, help = "Excluded file extension(s)", long_help = "List of extensions, that will be removed from search.\n ")]
+    pub excluded_extensions: Vec<String>,
     #[clap(flatten)]
     pub file_to_save: FileToSave,
     #[clap(flatten)]
     pub json_compact_file_to_save: JsonCompactFileToSave,
     #[clap(flatten)]
     pub json_pretty_file_to_save: JsonPrettyFileToSave,
-    #[clap(flatten)]
-    pub not_recursive: NotRecursive,
+    #[clap(short = 'R', long, help = "Prevents from recursive check of folders")]
+    pub not_recursive: bool,
     #[cfg(target_family = "unix")]
+    #[clap(short = 'X', long, help = "Exclude files on other filesystems")]
+    pub exclude_other_filesystems: bool,
     #[clap(flatten)]
-    pub exclude_other_filesystems: ExcludeOtherFilesystems,
+    pub do_not_print: DoNotPrint,
+    #[clap(short = 'W', long, help = "Ignore error code when files are found")]
+    pub ignore_error_code_on_found: bool,
+    #[clap(short = 'H', long, help = "Disable cache")]
+    pub disable_cache: bool,
+}
+
+#[derive(Debug, clap::Args)]
+pub struct DoNotPrint {
+    #[clap(short = 'N', long, help = "Do not print the results to the console")]
+    pub do_not_print_results: bool,
+    #[clap(short = 'M', long, help = "Do not print info/warnings/errors from the program to console")]
+    pub do_not_print_messages: bool,
 }
 
 #[derive(Debug, clap::Args)]
@@ -597,85 +503,32 @@ pub struct DMethod {
         long,
         default_value = "NONE",
         value_parser = parse_delete_method,
-        help = "Delete method (AEN, AEO, ON, OO, HARD)",
-        long_help = "Methods to delete the files.\nAEN - All files except the newest,\nAEO - All files except the oldest,\nON - Only 1 file, the newest,\nOO - Only 1 file, the oldest\nHARD - create hard link\nNONE - not delete files"
+        help = "Delete method (AEN, AEO, ON, OO, AEB, AES, OE, OS, HARD)",
+        long_help = "Methods to delete the files.\nAEN - All files except the newest,\nAEO - All files except the oldest,\nON - Only 1 file, the newest,\nOO - Only 1 file, the oldest\nAEB - All files except the biggest,\nAES - All files except the smallest,\nOB - Only 1 file, the biggest,\nOS - Only 1 file, the smallest\nHARD - create hard link\nNONE - not delete files"
     )]
     pub delete_method: DeleteMethod,
 }
 
-#[derive(Debug, clap::Args)]
-pub struct Directories {
-    #[clap(
-        short,
-        long,
-        required = true,
-        help = "Directorie(s) to search",
-        long_help = "List of directorie(s) which will be searched(absolute path)"
-    )]
-    pub directories: Vec<PathBuf>,
-}
-
-#[derive(Debug, clap::Args)]
-pub struct ExcludedDirectories {
-    #[clap(
-        short,
-        long,
-        help = "Excluded directorie(s)",
-        long_help = "List of directorie(s) which will be excluded from search(absolute path)"
-    )]
-    pub excluded_directories: Vec<PathBuf>,
-}
-
-#[derive(Debug, clap::Args)]
-pub struct ExcludedItems {
-    #[clap(
-        short = 'E',
-        long,
-        help = "Excluded item(s)",
-        long_help = "List of excluded item(s) which contains * wildcard(may be slow, so use -e where possible)"
-    )]
-    pub excluded_items: Vec<String>,
-}
-
-#[derive(Debug, clap::Args)]
-pub struct AllowedExtensions {
-    #[clap(
-        short = 'x',
-        long,
-        help = "Allowed file extension(s)",
-        long_help = "List of checked files with provided extension(s). There are also helpful macros which allow to easy use a typical extensions like:\nIMAGE(\"jpg,kra,gif,png,bmp,tiff,hdr,svg\"),\nTEXT(\"txt,doc,docx,odt,rtf\"),\nVIDEO(\"mp4,flv,mkv,webm,vob,ogv,gifv,avi,mov,wmv,mpg,m4v,m4p,mpeg,3gp\") or\nMUSIC(\"mp3,flac,ogg,tta,wma,webm\")\n "
-    )]
-    pub allowed_extensions: Vec<String>,
-}
-
-#[derive(Debug, clap::Args)]
-pub struct NotRecursive {
-    #[clap(short = 'R', long, help = "Prevents from recursive check of folders")]
-    pub not_recursive: bool,
-}
-
-#[derive(Debug, clap::Args)]
-pub struct ThreadNumber {
-    #[clap(short = 'T', long, default_value = "0", help = "Limits thread number, 0(default) will use all available threads")]
-    pub thread_number: usize,
-}
-
-#[cfg(target_family = "unix")]
-#[derive(Debug, clap::Args)]
-pub struct ExcludeOtherFilesystems {
-    #[clap(short = 'X', long, help = "Exclude files on other filesystems")]
-    pub exclude_other_filesystems: bool,
-}
-
 #[derive(Debug, clap::Args)]
 pub struct FileToSave {
     #[clap(short, long, value_name = "file-name", help = "Saves the results into the formatted txt file")]
     pub file_to_save: Option<PathBuf>,
 }
 
+#[derive(Debug, clap::Args)]
+pub struct ReferenceDirectories {
+    #[clap(
+        short,
+        long,
+        help = "Reference directorie(s) to search",
+        long_help = "List of directorie(s) which will be searched(absolute path) - this directories are set as reference folders, so will not be visible in the results"
+    )]
+    pub reference_directories: Vec<PathBuf>,
+}
+
 #[derive(Debug, clap::Args)]
 pub struct JsonCompactFileToSave {
-    #[clap(short, long, value_name = "json-file-name", help = "Saves the results into the compact json file")]
+    #[clap(short = 'C', long, value_name = "json-file-name", help = "Saves the results into the compact json file")]
     pub compact_file_to_save: Option<PathBuf>,
 }
 
@@ -703,6 +556,12 @@ pub struct DryRun {
     pub dry_run: bool,
 }
 
+#[derive(Debug, clap::Args)]
+pub struct IgnoreSameSize {
+    #[clap(short = 'J', long, help = "Ignore files with the same size, leaving only one file of each size")]
+    pub ignore_same_size: bool,
+}
+
 impl FileToSave {
     pub fn file_name(&self) -> Option<&str> {
         if let Some(file_name) = &self.file_to_save {
@@ -763,6 +622,16 @@ fn parse_checking_method_duplicate(src: &str) -> Result<CheckingMethod, &'static
     }
 }
 
+fn parse_broken_files(src: &str) -> Result<CheckedTypes, &'static str> {
+    match src.to_ascii_lowercase().as_str() {
+        "pdf" => Ok(CheckedTypes::PDF),
+        "audio" => Ok(CheckedTypes::AUDIO),
+        "image" => Ok(CheckedTypes::IMAGE),
+        "archive" => Ok(CheckedTypes::ARCHIVE),
+        _ => Err("Couldn't parse the broken files type (allowed: PDF, AUDIO, IMAGE, ARCHIVE)"),
+    }
+}
+
 fn parse_checking_method_same_music(src: &str) -> Result<CheckingMethod, &'static str> {
     match src.to_ascii_lowercase().as_str() {
         "tags" => Ok(CheckingMethod::AudioTags),
@@ -779,7 +648,11 @@ fn parse_delete_method(src: &str) -> Result<DeleteMethod, &'static str> {
         "hard" => Ok(DeleteMethod::HardLink),
         "on" => Ok(DeleteMethod::OneNewest),
         "oo" => Ok(DeleteMethod::OneOldest),
-        _ => Err("Couldn't parse the delete method (allowed: AEN, AEO, ON, OO, HARD)"),
+        "aeb" => Ok(DeleteMethod::AllExceptBiggest),
+        "aes" => Ok(DeleteMethod::AllExceptSmallest),
+        "ob" => Ok(DeleteMethod::OneBiggest),
+        "os" => Ok(DeleteMethod::OneSmallest),
+        _ => Err("Couldn't parse the delete method (allowed: AEN, AEO, ON, OO, HARD, AEB, AES, OB, OS)"),
     }
 }
 
@@ -834,7 +707,8 @@ fn parse_similar_hash_algorithm(src: &str) -> Result<HashAlg, String> {
         "blockhash" => HashAlg::Blockhash,
         "vertgradient" => HashAlg::VertGradient,
         "doublegradient" => HashAlg::DoubleGradient,
-        _ => return Err("Couldn't parse the hash algorithm (allowed: Mean, Gradient, Blockhash, VertGradient, DoubleGradient)".to_string()),
+        "median" => HashAlg::Median,
+        _ => return Err("Couldn't parse the hash algorithm (allowed: Mean, Gradient, Blockhash, VertGradient, DoubleGradient, Median)".to_string()),
     };
     Ok(algorithm)
 }
